The /auth/token endpoint manages token-based authentication functionality.
The `/auth/token` endpoint manages token-based authentication functionality. Reference: https://www.vaultproject.io/api-docs/auth/token
The token auth endpoints manage token authentication functionality.
The token auth endpoints manage token authentication functionality.
(create-orphan-token! client params)Create a new auth token with no parent. This method uses the
/auth/token/create-orphan endpoint.
Parameters are the same as for the create-token! call.
Create a new auth token with no parent. This method uses the `/auth/token/create-orphan` endpoint. Parameters are the same as for the `create-token!` call.
(create-role-token! client role-name params)Create a new auth token in the named role. This method uses the
/auth/token/create/:role-name endpoint.
Parameters are the same as for the create-token! call.
Create a new auth token in the named role. This method uses the `/auth/token/create/:role-name` endpoint. Parameters are the same as for the `create-token!` call.
(create-token! client params)Create a new auth token. The token will be a child of the current one
unless the :no-parent option is true. This method uses the
/auth/token/create endpoint.
For parameter options, see: https://www.vaultproject.io/api-docs/auth/token#create-token
Create a new auth token. The token will be a child of the current one unless the `:no-parent` option is true. This method uses the `/auth/token/create` endpoint. For parameter options, see: https://www.vaultproject.io/api-docs/auth/token#create-token
(lookup-token client params)Look up auth information about a token.
Depending on the parameters, this method operates on:
:token:accessorLook up auth information about a token. Depending on the parameters, this method operates on: - a directly-provided `:token` - a token `:accessor` - otherwise, the currently-authenticated token
(renew-token! client params)Renew a lease associated with a token. Token renewal is possible only if there is a lease associated with it.
Depending on the parameters, this method operates on:
:token:accessorThe parameters may also include a requested :increment value.
Renew a lease associated with a token. Token renewal is possible only if there is a lease associated with it. Depending on the parameters, this method operates on: - a directly-provided `:token` - a token `:accessor` - otherwise, the currently-authenticated token The parameters may also include a requested `:increment` value.
(revoke-token! client params)Revoke a token and all child tokens. When the token is revoked, all dynamic secrets generated with it are also revoked. Returns nil.
Depending on the parameters, this method operates on:
:token:accessorRevoke a token and all child tokens. When the token is revoked, all dynamic secrets generated with it are also revoked. Returns nil. Depending on the parameters, this method operates on: - a directly-provided `:token` - a token `:accessor` - otherwise, the currently-authenticated token
(resolve-auth! client)Look up the currently-authenticated token, merging updated information into the client's auth info. Returns the updated auth data.
Look up the currently-authenticated token, merging updated information into the client's auth info. Returns the updated auth data.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |