Vault HTTP client and core functions.
Vault HTTP client and core functions.
(http-client address & {:as opts})Create a new HTTP Vault client. The address should be an http:// or
https:// URL.
Options:
:flow (vault.client.flow/Handler)
Custom control flow handler to use with the client. Defaults to
vault.client.flow/sync-handler.
:http-opts (map)
Additional options to pass to all HTTP requests.
Create a new HTTP Vault client. The address should be an `http://` or `https://` URL. Options: - `:flow` ([[vault.client.flow/Handler]]) Custom control flow handler to use with the client. Defaults to [[vault.client.flow/sync-handler]]. - `:http-opts` (map) Additional options to pass to all HTTP requests.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |