Clojure only.

vault.sys.health

The /sys/health endpoint is used to check the health status of Vault.

Reference: https://www.vaultproject.io/api-docs/system/health

The `/sys/health` endpoint is used to check the health status of Vault.

Reference: https://www.vaultproject.io/api-docs/system/health
raw docstring

APIcljprotocol

Methods for checking the health of Vault.

Methods for checking the health of Vault.

read-healthclj

(read-health client params)

Return the health status of Vault.

Return the health status of Vault.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries