Vault Azure auth method
Vault Azure auth method
(login client params)Logs in to Vault using Azure credentials, as per https://developer.hashicorp.com/vault/docs/auth/azure.
The params map is transformed into snake keys and used as the
request body to the login endpoint. See https://developer.hashicorp.com/vault/api-docs/auth/azure#login
for all supported parameters.
Common parameters are:
:role - Vault role name:jwt - Azure access token:subscription-id - Azure subscription ID:resource-group-name - Azure resource group name:vm-name - When using an Azure VM's system-assigned or user-assigned identity, the name of the Azure VMLogs in to Vault using Azure credentials, as per <https://developer.hashicorp.com/vault/docs/auth/azure>. The `params` map is transformed into snake keys and used as the request body to the login endpoint. See <https://developer.hashicorp.com/vault/api-docs/auth/azure#login> for all supported parameters. Common parameters are: - `:role` - Vault role name - `:jwt` - Azure access token - `:subscription-id` - Azure subscription ID - `:resource-group-name` - Azure resource group name - `:vm-name` - When using an Azure VM's system-assigned or user-assigned identity, the name of the Azure VM
(with-mount client mount)Configures the mount point of the auth method, if it is not the default.
Returns a new client. If mount is nil, returns a client with the default
mount point.
Configures the mount point of the auth method, if it is not the default. Returns a new client. If `mount` is nil, returns a client with the default mount point.
Default mount point for the auth method.
Default mount point for the auth method.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |